Learn R Programming

Countr (version 3.6.1)

chiSq_gof: Formal Chi-square goodness-of-fit test

Description

Carry out the formal chi-square goodness-of-fit test described by Cameron (2013).

Usage

chiSq_gof(object, breaks, ...)

# S3 method for renewal chiSq_gof(object, breaks, ...)

# S3 method for negbin chiSq_gof(object, breaks, ...)

# S3 method for glm chiSq_gof(object, breaks, ...)

Value

data.frame

Arguments

object

an object from class renewal.

breaks

integer values at which the breaks shoudl happen. The function will compute the observed frequencies in the intervals [breaks[i], breaks[i + 1]).

...

currently not used.

Details

The test is a conditional moment test described in details in Cameron (2013, Section 5.3.4). We compute the asymptotically equivalent outer product of the gradient version which is justified for renewal models (fully parametric + parameters based on MLE).

References

cameron2013regressionCountr

See Also

chiSq_pearson