Carry out the formal chi-square goodness-of-fit test described by Cameron (2013).
chiSq_gof(object, breaks, ...)# S3 method for renewal
chiSq_gof(object, breaks, ...)
# S3 method for negbin
chiSq_gof(object, breaks, ...)
# S3 method for glm
chiSq_gof(object, breaks, ...)
data.frame
an object from class renewal.
integer values at which the breaks shoudl happen. The function
will compute the observed frequencies in the intervals [breaks[i],
breaks[i + 1]).
currently not used.
The test is a conditional moment test described in details in Cameron (2013, Section 5.3.4). We compute the asymptotically equivalent outer product of the gradient version which is justified for renewal models (fully parametric + parameters based on MLE).
cameron2013regressionCountr
chiSq_pearson